﻿using System;
using System.Collections.Generic;
using System.Linq;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Audio;
using Microsoft.Xna.Framework.Content;
using Microsoft.Xna.Framework.GamerServices;
using Microsoft.Xna.Framework.Graphics;
using Microsoft.Xna.Framework.Input;
using Microsoft.Xna.Framework.Media;
using Microsoft.Xna.Framework.Net;
using Microsoft.Xna.Framework.Storage;

///
/// SpriteNode - texture & text
///
namespace XNA4KinectHandler
{
    public class SpriteNode
    {
        protected SpriteBatch spriteBatch;
        public float Alpha
        {
            get;
            set;
        }
        public float Size // 점점크게 할때 사용
        {
            get;
            set;
        }

        protected SpriteNode(SpriteBatch spriteBatch)
        {
            this.spriteBatch = spriteBatch; // new SpriteBatch(game.GraphicsDevice);
        }
    }

    public class SpriteImageNode : SpriteNode
    {
        public Texture2D Texture
        {
            get;
            set;
        }

        public Rectangle SrcRect
        {
            get;
            set;
        }
        public Vector2 TextureSize
        {
            get
            {
                return new Vector2(Texture.Width, Texture.Height);
            }
        }

        public SpriteImageNode(SpriteBatch spriteBatch, Texture2D texture)
            : base(spriteBatch)
        {
            this.Texture = texture;
            if (this.Texture == null)
            {
                System.Diagnostics.Trace.WriteLine("ERROR in Texture Loading");
                return;
            }
        }

        public virtual void Draw(Vector2 pos)
        {
            this.SrcRect = new Rectangle((int)pos.X, (int)pos.Y, this.Texture.Width, this.Texture.Height);
            if (this.Texture != null)
            {
                spriteBatch.Begin();
                spriteBatch.Draw(this.Texture, this.SrcRect, Color.White);
                spriteBatch.End();
            }
        }
    }

    public class SpriteTextNode : SpriteNode
    {
        public SpriteFont Font
        {
            get;
            set;
        }

        public SpriteTextNode(SpriteBatch spriteBatch, SpriteFont font)
            : base(spriteBatch)
        {
            this.Font = font;
        }

        public void Draw(string text, Vector2 pos, Color color)
        {
            spriteBatch.Begin();
            spriteBatch.DrawString(this.Font, text, pos, color);
            spriteBatch.End();
        }
    }
}
